@@ -5,6 +5,8 @@ from .chmod600 import chmod600  # noqa: F401
 from .run_cmd import run_cmd  # noqa: F401
 from .run_cmd1 import run_cmd1  # noqa: F401
 from .gen_keypair import gen_keypair  # noqa: F401
+from .setup_git import setup_git  # noqa: F401
+from .setup_ssh_tunnel import setup_ssh_tunnel  # noqa: F401
 
 __version__ = "0.1.2"
 
@@ -14,4 +16,6 @@ __all__ = (
     "chmod600",
     "run_cmd",
     "gen_keypair",
+    "setup_git",
+    "setup_ssh_tunnel",
 )
