@@ -7,18 +7,22 @@ import re
 # import subprocess as sp  # noqa: F401
 from logzero import logger
 
+from .chmod600 import chmod600
+
 
 # fmt: off
 def create_file(
         content: str = "",
         dest: Union[Path, str] = Path("~/.ssh/gh-key").expanduser(),
         overwrite: bool = False,
+        setmode: bool = False,  # if True, chmode600
 ) -> Optional[Path]:
     # fmt: on
     """
     Create a file if it does not exist.
 
     Overwrite existing file only if set to True.
+    Set mode to 600 if setmode is True (default false)
     """
     # unticipate people from another world
     pattern = re.compile(r"\$home|%userprofile%?", re.IGNORECASE)
@@ -48,4 +52,7 @@ def create_file(
         logger.error("dest.write_text exc: %s", exc)
         return None
 
+    if setmode:
+        chmod600(dest)
+
     return dest
